@@ -1,39 +1,41 @@
 package HTML::Perlinfo;
-BEGIN { %Seen = %INC }
+BEGIN { %HTML::Perlinfo::Seen = %INC }
 
 use strict;
 use warnings;
-use Carp (); 
+use Carp ();
 
 use HTML::Perlinfo::Apache;
-use HTML::Perlinfo::Modules; 
+use HTML::Perlinfo::Modules;
 use HTML::Perlinfo::Common;
 
 use base qw(Exporter HTML::Perlinfo::Base);
 our @EXPORT = qw(perlinfo);
 
-our $VERSION = '1.64';
+our $VERSION = '1.66';
 
 sub perlinfo {
   my ($opt) = @_;
   $opt = 'INFO_ALL' unless $opt;
- 
+
   error_msg("Invalid perlinfo() parameter: @_")
-  if (($opt !~ /^INFO_(?:ALL|GENERAL|CONFIG|VARIABLES|APACHE|MODULES|LICENSE|LOADED)$/) || @_ > 1); 
- 
+  if (($opt !~ /^INFO_(?:ALL|GENERAL|CONFIG|VARIABLES|APACHE|MODULES|LICENSE|LOADED)$/) || @_ > 1);
+
   $opt = lc $opt;
   my $p = HTML::Perlinfo->new();
   $p->$opt;
 
 }
-%INC = %HTML::Perlinfo::Seen;
+foreach my $key (%HTML::Perlinfo::Seen) {
+    $INC{$key} = $HTML::Perlinfo::Seen{$key} unless exists $INC{$key};
+}
 1;
 __END__
 =pod
 
 =head1 NAME
 
-HTML::Perlinfo - Display a lot of Perl information in HTML format 
+HTML::Perlinfo - Display a lot of Perl information in HTML format
 
 =head1 SYNOPSIS
 
@@ -193,9 +195,8 @@ Some might notice that HTML::Perlinfo shares the look and feel of the PHP functi
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-html-perlinfo@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Perlinfo>.
-I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+If you'd like to report an issue you can use github's
+L<issue tracker|https://github.com/mixedconnections/HTML-Perlinfo/issues>.
 
 =head1 SEE ALSO
 
